"""
    file        mqtt_events.py
    brief       SpringCore - SpringPark demonstration
    author      Matthieu Barreteau <matthieu.b@springcard.com>
    date        27/01/2021
 
    copyright   Copyright (c) 2021 SPRINGCARD SAS, FRANCE - www.springcard.com
    version     MBA 27/01/2021: initial release, plain connexion
    """
import logging

class mqtt_events:
    # this event is triggered by the paho-mqtt client on connection
    def on_connect(client, userdata, flags, rc):
        if "aws_mode" in userdata:
            logging.info( f"Connected to AWS server, code={rc}" )
        else:
            logging.info( f"Connected to MQTT server, code={rc}" )

        if "subscriptions" in userdata:
            if len( userdata[ "subscriptions" ] ):                
                for atopic, qos in userdata[ "subscriptions" ]:
                    logging.info( f"Subscribing to topic {atopic} (qos={qos})" )
                client.subscribe( userdata[ "subscriptions" ] )
            else:
                logging.warning( "No topic to subscribe to!" )


    # this event is triggered by the paho-mqtt client on disconnection
    def on_disconnect(client, userdata, rc):
        if rc != 0:        
            if "aws_mode" in userdata:
                logging.error( f"Disconnected from AWS server, code={rc}!" )
                logging.info( f"AWS disconnects you on the first connection, please retry!" )
            else:
                logging.error( f"Disconnected from server, code={rc}!" )
        else:
            logging.error( "Disconnected from server!" )
        
        # set ou exit event!
        userdata[ "exit_event" ].set()

    # this event is triggered by the paho-mqtt client on new message
    def on_message(client, userdata, msg):
        if "callback" in userdata:
            """ Here we could add a filter based on topic name
            to branch to different callbacks """
            userdata[ "callback" ]( client, userdata, msg )
        else:
            logging.info( f"{msg.topic} > {msg.payload}" )

# EOF